@@ -1,5 +1,5 @@
 use futures::executor;
-use nstd_core::NSTDSlice;
+use nstd_core::slice::NSTDSlice;
 use nstd_gui::{NSTDWindow, NSTDWindowSize};
 use std::{
     ffi::CString,
@@ -710,7 +710,7 @@ pub unsafe extern "C" fn nstd_std_gl_render_pass_draw_indexed(
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
 pub unsafe extern "C" fn nstd_std_gl_device_info_free(device_info: &mut NSTDGLDeviceInfo) {
-    CString::from_raw(device_info.name);
+    drop(CString::from_raw(device_info.name));
     device_info.name = ptr::null_mut();
 }
 
